@@ -3,7 +3,8 @@ from typing import TypeVar
 import numpy as np
 
 from ..chunk import Chunk
-from ..types import FloatArray, PType
+from ..chunk_types import FloatArray, PType
+from ..exceptions import ValidationError
 
 T = TypeVar("T", bound="Boxes")
 
@@ -38,7 +39,16 @@ class Boxes(Chunk):
     def validate(self) -> None:
         """Check validity of boxes array."""
         if not self.shape or self.shape[-1] != 4:
-            raise ValueError("Box arrays must have size-4 dimensions")
+            raise ValidationError("Box arrays must have size-4 dimensions")
+
+    @property
+    def scale(self) -> FloatArray:
+        """Scaling array."""
+        if self._scale is None:
+            width = self.image_width
+            height = self.image_height
+            self._scale = np.array([width, height, width, height])
+        return self._scale
 
     @property
     def is_relative(self) -> bool:
@@ -140,7 +150,7 @@ class Boxes(Chunk):
             PType.relative_tlwh,
         }
         if self.ptype not in known_box_parameterizations:
-            raise ValueError(f"Unknown box parameterization: {self.ptype.name}")
+            raise ValidationError(f"Unknown box parameterization: {self.ptype.name}")
 
     @property
     def x(self) -> FloatArray:
