@@ -5,10 +5,12 @@ from operator import itemgetter
 from pathlib import Path
 from typing import Any, Iterator, Optional, Union
 
+import datumaro as dm
 import numpy as np
 import numpy.typing as npt
 
-from ..types import PType
+from ..chunk_types import PType
+from ..exceptions import ValidationError
 from .augmented_boxes import AugmentedBoxes
 from .frame_boxes import FrameBoxes, _is_2d
 from .single_augmented_box import SingleAugmentedBox
@@ -44,6 +46,8 @@ class FrameAugmentedBoxes(AugmentedBoxes):
     [0.  0.  1.  1.  0.5 3. ]
     """
 
+    empty_shape: tuple[int, int] = (0, 6)
+
     def validate(self) -> None:
         """Check validity of boxes array."""
         super().validate()
@@ -86,7 +90,22 @@ class FrameAugmentedBoxes(AugmentedBoxes):
         path: str = "/",
         label_names: Optional[list[str]] = None,
     ) -> None:
-        """Write Darwin annotation dict to disk."""
+        """
+        Write Darwin annotation dict to disk.
+
+        Parameters
+        ----------
+        output_path : str
+            The full path (including filename) where the Darwin annotation will be written on disk
+        filename : str
+            The fimename of the image or video as it's referenced within the Darwin
+        path : str, optional
+            The path of the file within Darwin. The path starts at root ("/"),
+            and expands including the folders in which the resource is stored within Darwin.
+        label_names : list of str, optional
+            The names of the labeled classes annotated in the image or video. If None,
+            "Unknown" will be used.
+        """
         with open(output_path, "w") as f:
             f.write(
                 json.dumps(
@@ -94,6 +113,33 @@ class FrameAugmentedBoxes(AugmentedBoxes):
                 )
             )
 
+    @classmethod
+    def from_dataset_item(
+        cls: type["FrameAugmentedBoxes"], dataset_item: dm.DatasetItem
+    ) -> "FrameAugmentedBoxes":
+        """Create FrameAugmentedBoxes from a Datumaro DatasetItem object."""
+        image: dm.Image = dataset_item.media
+        image_height, image_width = image.size
+        boxes = []
+        score = 1.0
+        for annotation in dataset_item.annotations:
+            if not isinstance(annotation, dm.Bbox):
+                continue
+            x1, y1, x2, y2 = annotation.points
+            label = annotation.label
+            boxes.append([x1, y1, x2, y2, score, label])
+        data: npt.NDArray[np.float64]
+        if len(boxes):
+            data = np.array(boxes).astype("float64")
+        else:
+            data = np.zeros((0, 6), "float64")
+        return cls(
+            data,
+            ptype=PType.absolute_tlbr,
+            image_width=image_width,
+            image_height=image_height,
+        )
+
     @classmethod
     def from_darwin_dict(
         cls: type["FrameAugmentedBoxes"],
@@ -157,11 +203,11 @@ class FrameAugmentedBoxes(AugmentedBoxes):
     def add_box(self, box: SingleAugmentedBox) -> "FrameAugmentedBoxes":
         """Concatenate a single augmented box."""
         if self.ptype != box.ptype:
-            raise ValueError(
+            raise ValidationError(
                 "SingleAugmentedBox with different PType cannot be concatenated"
             )
         if self.metadata_kwargs != box.metadata_kwargs:
-            raise ValueError(
+            raise ValidationError(
                 "SingleAugmentedBox with different metadata cannot be concatenated"
             )
         return FrameAugmentedBoxes(
