@@ -9,8 +9,8 @@ from typing import Any, TypeVar
 
 import numpy as np
 
+from .chunk_types import FloatArray, PType
 from .exceptions import ValidationError
-from .types import FloatArray, PType
 
 T = TypeVar("T", bound="Chunk")
 
@@ -140,15 +140,6 @@ class Chunk(FloatArray):
             raise ValidationError("start_time not set")
         return self._start_time
 
-    @property
-    def scale(self) -> FloatArray:
-        """Scaling array."""
-        if self._scale is None:
-            width = self.image_width
-            height = self.image_height
-            self._scale = np.array([width, height, width, height])
-        return self._scale
-
     @property
     def duration(self) -> float:
         """Duration of the chunk in seconds."""
@@ -204,11 +195,11 @@ class Chunk(FloatArray):
     ) -> T:
         """Create chunk from chunk dict."""
         data: FloatArray
-        if len(chunk_dict["data"]) == 0 and dims:
+        if np.array(chunk_dict["data"]).size == 0 and dims:
             if "tracking" in cls.__name__.lower():
-                data = np.zeros((0, 0, dims), "float64")
+                data = np.zeros((len(chunk_dict["data"]), 0, dims), "float64")
             else:
-                data = np.zeros((0, dims), "float64")
+                data = np.zeros((len(chunk_dict["data"]), dims), "float64")
         else:
             data = np.array(chunk_dict["data"]).astype("float64")
         data[data == None] = np.nan
